@@ -10,9 +10,8 @@ $EXTRACTXML --extract \
         --parse-unquoted='--context=HTML:%(tag)s --tag-regex=^(?:title|body|p|h[1-6])$ --recursive --strip' \
         ./examples/*.step ./tutorials/*.step --output=examples.cpp
 
-# Temporary commented-out
-#$XGETTEXT objinfo.cpp -o $podir/step_objinfo_files.pot
-#$XGETTEXT examples.cpp -o $podir/step_example_files.pot
+$XGETTEXT objinfo.cpp -o $podir/step_objinfo_files.pot
+$XGETTEXT examples.cpp -o $podir/step_example_files.pot
 
 rm -f objinfo.cpp
 rm -f examples.cpp
